@@ -1,7 +1,7 @@
 package Net::IMAP::Client;
 
 use vars qw[$VERSION];
-$VERSION = '0.9502';
+$VERSION = '0.9503';
 
 use strict;
 use warnings;
@@ -27,6 +27,7 @@ my %DEFAULT_ARGS = (
     ssl_verify_peer => 1,
     socket   => undef,
     _cmd_id  => 0,
+    ssl_options => {},
 );
 
 sub new {
@@ -312,10 +313,13 @@ sub search {
     my ($ok, $lines) = $self->_tell_imap($cmd => "$sort$charset $criteria", 1);
     if ($ok) {
         # it makes no sense to employ the full token parser here
-        my $line = $lines->[0]->[0];
-        $line =~ s/^\*\s+(?:SEARCH|SORT)\s+//ig;
-        $line =~ s/\s*$//g;
-        return [ map { $_ + 0 } split(/\s+/, $line) ];
+        # read past progress messages lacking initial '*'
+		foreach my $line (@{$lines->[0]}) {
+			if ($line =~ s/^\*\s+(?:SEARCH|SORT)\s+//ig) {
+				$line =~ s/\s*$//g;
+				return [ map { $_ + 0 } split(/\s+/, $line) ];
+			}
+		}
     }
 
     return undef;
@@ -639,12 +643,10 @@ sub _get_ssl_config {
 
     return %ssl_config;
 }
-
 sub _get_socket {
     my ($self) = @_;
-    unless ($self->{socket}) {
-        if ($self->{ssl}) {
-            $self->{socket} = IO::Socket::SSL->new(
+     my $socket = $self->{socket} ||= ($self->{ssl} ? 'IO::Socket::SSL' : 'IO::Socket::INET')->new(
+			( ( %{$self->{ssl_options}} ) x !!$self->{ssl} ), 
                 PeerAddr => $self->_get_server,
                 PeerPort => $self->_get_port,
                 Timeout  => $self->_get_timeout,
@@ -652,19 +654,6 @@ sub _get_socket {
                 Blocking => 1,
                 $self->_get_ssl_config,
             ) or die "failed connect or ssl handshake: $!,$IO::Socket::SSL::SSL_ERROR";
-        }
-        else {
-            $self->{socket} = IO::Socket::INET->new(
-                PeerAddr => $self->_get_server,
-                PeerPort => $self->_get_port,
-                Timeout  => $self->_get_timeout,
-                Proto    => 'tcp',
-                Blocking => 1,
-            ) or die "Can't connect : $@";
-        }
-    }
-    my $socket = $self->{socket};
-
     $socket->sockopt(SO_KEEPALIVE, 1);
     return $socket;
 }
@@ -1234,6 +1223,10 @@ On linux, by default is '/etc/ssl/certs/'
 at least one of ssl_ca_file and ssl_ca_path is needed for ssl verify
  server
 
+=item - B<ssl_options> (HASHREF, optional)
+
+Optional arguments to be passed to the L<IO::Socket::SSL> object.
+
 =item - B<uid_mode> (BOOL, optional, default TRUE)
 
 Whether to use UID command (see RFC3501).  Recommended.
